@@ -1,7 +1,18 @@
 from enum import IntEnum
+from typing import Dict
 
 
 class Book(IntEnum):
+    """Book is an IntEnum that contains all of the books of the Bible
+
+    :param name: the unique text identifier of the book
+    :type name: str
+    :param value: the unique number identifier of the book
+    :type value: int
+    :param title: the common English name of the book
+    :type title: str
+    """
+
     GENESIS = 1
     EXODUS = 2
     LEVITICUS = 3
@@ -76,11 +87,11 @@ class Book(IntEnum):
     MACCABEES_2 = 72
 
     @property
-    def title(self):
-        return _BOOK_TITLES.get(self)
+    def title(self) -> str:
+        return _BOOK_TITLES.get(self, "")
 
 
-_BOOK_TITLES = {
+_BOOK_TITLES: Dict[Book, str] = {
     Book.GENESIS: "Genesis",
     Book.EXODUS: "Exodus",
     Book.LEVITICUS: "Leviticus",
